@@ -1,7 +1,7 @@
 """
 common functions for callsignlookuptools
 ---
-Copyright 2021 classabbyamp, 0x5c
+Copyright 2021-2023 classabbyamp, 0x5c
 Released under the terms of the BSD 3-Clause license.
 """
 
@@ -43,3 +43,8 @@ def xml2dict(xml: Union[bytes, etree._Element], to_lower: bool = True) -> Dict:
         else:
             result[key] = value
     return result
+
+
+def is_callsign(callsign: str) -> bool:
+    """Check if a callsign is valid"""
+    return callsign.isascii() and callsign.replace("/", "").isalnum()
